@@ -1,5 +1,6 @@
 import click
 import sys
+import os
 import pathlib
 from time import time
 from click import BadParameter
@@ -116,6 +117,9 @@ def main(language, program_file, test_cases_in, compiler_args):
                 click.echo(process.stderr.decode().strip())
                 click.echo("---------------\n")
 
+    if file_to_run != program_file:
+        os.remove(file_to_run)
+
     if failed_cases == 0:
         click.echo("All tests passed successfully. ✅")
     else:
